# disable collection_artifact by default
%bcond_with collection_artifact

# disable collection by default since version 3.6.0 (1.3.5)
%bcond_with collection

%global collection_name_sap_install sap_install
%global collection_name_sap_infrastructure sap_infrastructure

%if 0%{?rhel}
%define package_name rhel-system-roles-sap
%global collection_namespace redhat
%else
%define package_name linux-system-roles-sap
%global collection_namespace community
%endif

# collection_version has to be increased by every rebuild
# otherwise, it cannot be uploaded to Automation Hub and Galaxy
# due to version conflict
%define collection_sap_install_version 1.5.2
%define collection_sap_infrastructure_version 1.1.1

%global collection_dir_sap_install collections/ansible_collections/%{collection_namespace}/%{collection_name_sap_install}
%global collection_dir_sap_infrastructure collections/ansible_collections/%{collection_namespace}/%{collection_name_sap_infrastructure}
%global mainid e4e63cd408561b39e11d6285ab81f32a999719db
%global commit_id_sap_install %{collection_sap_install_version}
%global commit_id_sap_infrastructure %{collection_sap_infrastructure_version}
%global rolename1 sap_general_preconfigure
%global rolename2 sap_ha_install_hana_hsr
%global rolename3 sap_hana_install
%global rolename4 sap_hana_preconfigure
%global rolename5 sap_ha_pacemaker_cluster
%global rolename6 sap_hypervisor_node_preconfigure
%global rolename7 sap_netweaver_preconfigure
%global rolename8 sap_swpm
%global rolename9 sap_vm_preconfigure
%global rolename10 sap_maintain_etc_hosts
%global src_owner linux-system-roles
%global github_repo_sap_install redhat.sap_install
%global github_repo_sap_infrastructure redhat.sap_infrastructure
%global rolename_sap_install %{rolename1} %{rolename2} %{rolename3} %{rolename4} %{rolename5} %{rolename7} %{rolename8} %{rolename10} 
%global rolename_sap_infrastructure %{rolename6} %{rolename9}
%global rolenames %{rolename_rhel}

Name: %{package_name}
Summary: System Roles to configure RHEL for running SAP NetWeaver- or SAP HANA-based products
Version: 3.8.5
Release: 1%{?dist}
License: GPL-3.0-or-later
Url: https://github.com/redhat-sap/community.sap_install
Source0: https://github.com/linux-system-roles/auto-maintenance/archive/%{mainid}/auto-maintenance-%{mainid}.tar.gz
Source1: https://github.com/redhat-sap/redhat.sap_install/archive/%{commit_id_sap_install}/%{github_repo_sap_install}-%{commit_id_sap_install}.tar.gz
Source2: https://github.com/redhat-sap/redhat.sap_infrastructure/archive/%{commit_id_sap_infrastructure}/%{github_repo_sap_infrastructure}-%{commit_id_sap_infrastructure}.tar.gz

# add tests files
Patch1: redhat.sap_install-1.3.4-add_tests.patch

# add tools files
Patch2: redhat.sap_install-1.3.4-add_tools.patch

# Fix check mode for sysctl
Patch3: redhat.sap_install-1.5.2-check_mode.patch

BuildArch: noarch

Requires: rhel-system-roles

BuildRequires: tar

# Requirements for galaxy_transform.py
BuildRequires: python3
%if 0%{?fedora} || 0%{?rhel} >= 8
BuildRequires: python3dist(ruamel.yaml)
Requires: python3-jmespath
Requires: python3-netaddr
%else
BuildRequires: python3-ruamel-yaml
Requires: python-jmespath
Requires: python-netaddr
%endif

# NOTE: ansible-core is in rhel-8.6 and newer, but not installable
# in buildroot as it depended on modular Python.
# It has been installable at buildtime in 8.8 and newer.
%if %{with collection}
%if 0%{?rhel} >= 8
BuildRequires: ansible-core >= 2.11.0
Requires: (ansible-core >= 2.11.0 or ansible >= 2.9.0)
%endif
%if %{undefined __ansible_provides}
Provides: ansible-collection(%{collection_namespace}.%{collection_name}) = %{version}
%endif
# be compatible with the usual Fedora Provides:
Provides: ansible-collection-%{collection_namespace}-%{collection_name} = %{version}-%{release}
%endif

# ansible-galaxy is available by ansible-core on RHEL 8.6 and newer at buildtime.
%define ansible_collection_build() ansible-galaxy collection build
%define ansible_collection_install() ansible-galaxy collection install -n -p %{buildroot}%{_datadir}/ansible/collections %{collection_namespace}-%{collection_name}-%{collection_sap_install_version}.tar.gz

%if 0%{?fedora} || 0%{?rhel} >= 8
%{!?ansible_collection_files:%define ansible_collection_files %{_datadir}/ansible/collections/ansible_collections/%{collection_namespace}/}
%else
%if %{?ansible_collection_files:0}%{!?ansible_collection_files:1}
%define ansible_collection_files %{_datadir}/ansible/collections/ansible_collections/%{collection_namespace}/
%endif
%endif

%description
Collection of Ansible roles which configures a RHEL system according
to applicable SAP notes so that any SAP software can be installed.

%if %{with collection_artifact}
%package collection-artifact
Summary: Collection artifact to import to Automation Hub / Ansible Galaxy

%description collection-artifact
Collection artifact for %{name}. This package contains:
 * %{collection_namespace}-%{collection_name}-%{collection_sap_install_version}.tar.gz
 * %{collection_namespace}-%{collection_name_sap_infrastructure}-%{collection_sap_infrastructure_version}.tar.gz
%endif

%prep
%setup -q -a1 -a2 -n auto-maintenance-%{mainid}

pushd %{github_repo_sap_install}-%{commit_id_sap_install}/
%patch -P1 -p1
%patch -P2 -p1
%patch -P3 -p1
popd

# unpack collection tar file
%if %{without collection}
mkdir -p %{collection_dir_sap_install} %{collection_dir_sap_infrastructure}
# sap_install collection
tar zxf %{github_repo_sap_install}-%{commit_id_sap_install}/%{collection_namespace}-%{collection_name_sap_install}-%{collection_sap_install_version}.tar.gz -C %{collection_dir_sap_install}
# sap_install collection, Fix check mode
pushd %{collection_dir_sap_install}/
%patch -P3 -p1
popd
# sap_infrastructure collection
tar zxf %{github_repo_sap_infrastructure}-%{commit_id_sap_infrastructure}/%{collection_namespace}-%{collection_name_sap_infrastructure}-%{commit_id_sap_infrastructure}.tar.gz -C %{collection_dir_sap_infrastructure}
%endif

# remove zero file and symlinks
find . -type f -size 0 -delete
find . -type l -delete

# fix python and bash shebangs
find -type f \( -iname "*.py" \) -exec sed -i '1s=^#! */usr/bin/\(python\|env python\)[23]\?=#!/usr/bin/python3=' {} +
find -type f \( -iname "*.sh" \) -exec sed -i '1s=^#! */bin/bash=#!/usr/bin/bash=' {} +

# remove json files, these are already present in the collection subdirectory
rm -f FILES.json MANIFEST.json

%build
%if %{with collection}
# create dest-path
mkdir .collections

for role in %{rolename_sap_install} ; do
LANG=en_US.utf-8 LC_ALL=en_US.utf-8 python3 lsr_role2collection.py --role "$role" \
    --src-path %{github_repo_sap_install}-%{commit_id_sap_install}/roles/"$role" \
    --src-owner %{src_owner} \
    --dest-path .collections \
    --namespace %{collection_namespace} \
    --collection %{collection_name} \
    --new-role "$new_role"
done

# update galaxy.yml
cp -p galaxy.yml .collections/ansible_collections/%{collection_namespace}/%{collection_name}

# update README.md 
cp %{github_repo_sap_install}-%{commit_id_sap_install}/README.md .collections/ansible_collections/%{collection_namespace}/%{collection_name}

# Build the collection
pushd .collections/ansible_collections/%{collection_namespace}/%{collection_name}/
%ansible_collection_build
popd
%endif

%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/ansible/roles \
         $RPM_BUILD_ROOT%{_pkgdocdir}

# create file selection for documents
echo "%dir %{_pkgdocdir}" > files_section.txt
cp %{github_repo_sap_install}-%{commit_id_sap_install}/README.md $RPM_BUILD_ROOT%{_pkgdocdir}/

echo "%{_pkgdocdir}/README.*" >> files_section.txt

# install sap_install roles
for role in %{rolename_sap_install} ; do
  mkdir -p $RPM_BUILD_ROOT%{_pkgdocdir}/$role
  cp -pR %{github_repo_sap_install}-%{commit_id_sap_install}/roles/$role $RPM_BUILD_ROOT%{_datadir}/ansible/roles/
  install -m 644 %{github_repo_sap_install}-%{commit_id_sap_install}/LICENSE \
    %{github_repo_sap_install}-%{commit_id_sap_install}/roles/$role/README.md \
    $RPM_BUILD_ROOT%{_pkgdocdir}/$role/
  echo "%dir %{_pkgdocdir}/$role" >> files_section.txt
done

# install sap_infrastructure roles
for role in %{rolename_sap_infrastructure} ; do
  mkdir -p $RPM_BUILD_ROOT%{_pkgdocdir}/$role
  cp -pR %{github_repo_sap_infrastructure}-%{commit_id_sap_infrastructure}/roles/$role $RPM_BUILD_ROOT%{_datadir}/ansible/roles/
  install -m 644 %{github_repo_sap_infrastructure}-%{commit_id_sap_infrastructure}/LICENSE \
    %{github_repo_sap_infrastructure}-%{commit_id_sap_infrastructure}/roles/$role/README.md \
    $RPM_BUILD_ROOT%{_pkgdocdir}/$role/
  echo "%dir %{_pkgdocdir}/$role" >> files_section.txt
done

# install collection files
%if %{with collection}
pushd .collections/ansible_collections/%{collection_namespace}/%{collection_name}/
%ansible_collection_install
popd
%else
cp -pR collections $RPM_BUILD_ROOT%{_datadir}/ansible/
%endif

# install collection_artifact
%if %{with collection_artifact}
# Copy collection artifact to /usr/share/ansible/collections/ for collection-artifact
pushd .collections/ansible_collections/%{collection_namespace}/%{collection_name}/
mv %{collection_namespace}-%{collection_name}-%{collection_sap_install_version}.tar.gz $RPM_BUILD_ROOT%{_datadir}/ansible/collections/
popd
%endif

%files -f files_section.txt
%dir %{_datadir}/ansible
%dir %{_datadir}/ansible/roles
%doc %{_pkgdocdir}/*/README.md
%license %{_pkgdocdir}/*/LICENSE
%{_datadir}/ansible/roles/*
%if %{with collection}
%{ansible_collection_files}
%else
%{_datadir}/ansible/collections
%endif
%if %{with collection_artifact}
%files collection-artifact
%{_datadir}/ansible/collections/%{collection_namespace}-%{collection_name}-%{collection_sap_install_version}.tar.gz
%endif

%changelog
* Wed Feb 05 2025 Than Ngo <than@redhat.com> - 3.8.5-1
- Fix check mode for largesend.conf on ppc64le
- Fix the package name of the RHEL 10 Power tools
  Related: RHEL-74075

* Tue Feb 04 2025 Than Ngo <than@redhat.com> - 3.8.4-1
- Related: RHEL-74075, Fix checkmode in sap_hana_preconfigure

* Fri Jan 31 2025 Than Ngo <than@redhat.com> - 3.8.3-1
- Related: RHEL-74075, Fix checkmode for sysctl

* Tue Jan 28 2025 Than Ngo <than@redhat.com> - 3.8.2-1
- Related: RHEL-74075, use redhat.sap_install for *_sap_install_collection

* Tue Jan 28 2025 Than Ngo <than@redhat.com> - 3.8.1-1
- Related: RHEL-74075, update redhat.sap_install to 1.5.2

* Mon Jan 20 2025 Than Ngo <than@redhat.com> - 3.8.0-1
- Resolves: RHEL-74075, new collcection redhat.sap_install and redhat.sap_infrastructure

* Tue May 14 2024 Than Ngo <than@redhat.com> - 3.7.0-1
- Resolves: RHEL-34806, rebase sap roles to version 1.3.7

* Mon Feb 05 2024 Than Ngo <than@redhat.com> - 3.6.0-4
- sap_hypervisor_node_preconfigure: fix for role name and path for included tasks
- update collection files
Related: RHEL-16895

* Thu Jan 25 2024 Than Ngo <than@redhat.com> - 3.6.0-3
- fix typo
Related: RHEL-16895

* Thu Jan 25 2024 Than Ngo <than@redhat.com> - 3.6.0-2
- add tests and tools
- fix bash and python shebangs
Related: RHEL-16895

* Mon Jan 22 2024 Than Ngo <than@redhat.com> - 3.6.0-1
- rebase sap roles to version 1.3.4
- add collection files
- update README files and add missing galaxy.yml, LICENSE
- fix syntax error for defining dependent collections in galaxy.yml
Resolves: RHEL-16895

* Thu May 04 2023 Than Ngo <than@redhat.com> - 3.5.0-2
- Related: #2185038, update README.md files

* Tue May 02 2023 Than Ngo <than@redhat.com> - 3.5.0-1
- update README, drop requirements-sap_swpm.yml
- migrate to SPDC license
- convert patch macro use to the most compatible syntax
- rebase sap roles to version 1.2.3
Resolves: #2185038

* Mon Jan 30 2023 Than Ngo <than@redhat.com> - 3.4.0-3
- Related: #2155870, rebase sap roles to version 1.2.1

* Thu Jan 19 2023 Than Ngo <than@redhat.com> - 3.4.0-2
- compat-sap-c++-10 is not available for RHEL 8.2 and earlier on hardware platform s390x
Related: #2155870

* Tue Jan 10 2023 Than Ngo <than@redhat.com> - 3.4.0-1
- Resolves: #2155870, rebase to 1.2.0 upstream version

* Mon Nov 28 2022 Than Ngo <than@redhat.com> - 3.3.0-5
- Related: #2143280, add missing repo vars for rhel-9.x

* Fri Nov 25 2022 Than Ngo <than@redhat.com> - 3.3.0-4
- Resolves: #2143280, drop deprecated paramater for Ansible 2.14

* Thu Jul 14 2022 Than Ngo <than@redhat.com> - 3.3.0-3
- more fixes, update README.md
Related: #2101373

* Tue Jul 12 2022 Than Ngo <than@redhat.com> - 3.3.0-2
- make the role Ansible 2.13 compliant
- get rid of all the new ansible-lint 6.3.0 errors for preconfigure and sap_hana_install roles
Resolves: #2101373

* Mon Jul 04 2022 Than Ngo <than@redhat.com> - 3.3.0-1
- Resolves: #2101373, include roles for setting up a two-node SAP HANA pacemaker cluster

* Wed Jun 08 2022 Than Ngo <than@redhat.com> - 3.2.0-5
- increase release
Related: #2065407

* Wed Jun 08 2022 Than Ngo <than@redhat.com> - 3.2.0-4
- sap_hana_preconfigure: using wrong variable name
- do not attempt to enable HANA repos for s390x
- sap_general_preconfigure: fix variable inclusion for RHEL minor releases
- sap_hana_preconfigure: Add vars for RHEL 9.1 managed nodes
- sap_hana_preconfigure: Fix issue #154
Related: #2065407

* Sun Mar 13 2022 Than Ngo <than@redhat.com> - 3.2.0-3
- Resolves: #2065407, new rebase

* Tue Feb 22 2022 Than Ngo <than@redhat.com> - 3.2.0-2
- Related: #2047282, new rebase, fixed collection basename

* Mon Jan 31 2022 Than Ngo <than@redhat.com> - 3.2.0-1
- Resolves: #2047282, Rebase to new upstream org sap-linuxlab

* Fri Dec 03 2021 Than Ngo <than@redhat.com> - 3.1.1-15
- Related: #2021579, ansible-lint cleanup

* Tue Nov 16 2021 Than Ngo <than@redhat.com> - 3.1.1-14
- Resolves: #2021579, ansible-lint cleanup

* Fri Oct 15 2021 Than Ngo <than@redhat.com> - 3.1.1-13
- Fix the version of the collection tar file

* Fri Oct 15 2021 Than Ngo <than@redhat.com> - 3.1.1-12
- Resolves: #2003630, Pepare the roles for ansible-core 2.11: Only use ansible.core modules

* Wed Sep 01 2021 Than Ngo <than@redhat.com> - 3.1.1-11
- fix yum group install errors on RHEL 7
- use grubby for setting tsx=on
- set min kernel version for RHEL 8.4 x86_64

* Fri Aug 20 2021 Than Ngo <than@redhat.com> - 3.1.1-10
- Related: #1977195, fix #149, #177, #193, #194

* Tue Aug 10 2021 Mohan Boddu <mboddu@redhat.com> - 3.1.1-9
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Fri Jul 16 2021 Than Ngo <than@redhat.com> - 3.1.1-8
- Related: #1977195, add missing vars/RedHat_9.yml in sap-netweaver-preconfigure

* Tue Jul 13 2021 Than Ngo <than@redhat.com> - 3.1.1-7
- Related: #1977195, add missing __sap_preconfigure_envgroups for RHEL 7.x and
  missing __sap_hana_preconfigure_req_repos variables for RHEL 8.5 and later

* Tue Jun 29 2021 Than Ngo <than@redhat.com> - 3.1.1-6
- Resolves: #1977195, make RHEL system roles for SAP RHEL9 compatible

* Mon Jun 28 2021 Than Ngo <than@redhat.com> - 3.1.1-5
- updated tarball, galaxy.yml, README.md

* Mon Jun 07 2021 Than Ngo <than@redhat.com> - 3.1.1-4
- update README.md
- Adding the -collection-artifact subpackage, enabled using
  "--with collection_artifact". It is used for importing to
  ansible galaxy/automation hub.

* Fri May 21 2021 Than Ngo <than@redhat.com> - 3.1.1-3
- convert roles to FQCN in the README files

* Thu May 20 2021 Than Ngo <than@redhat.com> - 3.1.1-2
- rename dashes by underscores and drop sap-

* Tue May 18 2021 Than Ngo <than@redhat.com> - 3.1.1-1
- rebase

* Wed Apr 14 2021 Than Ngo <than@redhat.com> - 3.1.0-3
- bz#1928398, rebuilt against new python-ruamel-yaml-0.15.100 for conversion problem

* Mon Mar 22 2021 Than Ngo <than@redhat.com> - 3.1.0-2
- rebase

* Tue Mar 02 2021 Than Ngo <than@redhat.com> - 3.1.0-1
- added support Transfer SAP roles into collection format

* Wed Feb 24 2021 Than Ngo <than@redhat.com> - 3.0.1-3
- Related: #1891642, fixed issue #125 in sap-preconfigure and #163 and #164 in sap-hana-preconfigure

* Thu Feb 18 2021 Than Ngo <than@redhat.com> - 3.0.1-2
- Related: #1891642, update sap-hana-preconfigure 3.0.1 and fixed Urls

* Thu Feb 18 2021 Than Ngo <than@redhat.com> - 3.0.1-1
- Related: #1891642, rebase to 3.0.1

* Mon Feb 15 2021 Than Ngo <than@redhat.com> - 3.0.0-2
- Related: #1891642, more fixes #145, #148, #149, #150 #147

* Thu Jan 28 2021 Than Ngo <than@redhat.com> - 3.0.0-1
- Resolves: #1891638, bug fixes
- Resolves: #1891642, new features

* Tue Jan 12 2021 Than Ngo <than@redhat.com> - 2.0.0-8
- RHEL 9.0.0 Alpha build

* Mon Sep 21 2020 Than Ngo <than@redhat.com> - 2.0.0-7
- Related: #1867027, fix #119

* Thu Aug 20 2020 Than Ngo <than@redhat.com> - 2.0.0-6
- Related: #1867027, fix #92

* Fri Aug 07 2020 Than Ngo <than@redhat.com> - 2.0.0-5
- Resolves: #1867027, more fixes for #89, #109, #110, #111, #112, #113, #114, #116

* Tue Jul 21 2020 Than Ngo <than@redhat.com> - 2.0.0-4
- Related: #1844190, more fixes for #84, #85, #86, #88, #98, #104, #105, #107

* Fri Jul 03 2020 Than Ngo <than@redhat.com> - 2.0.0-3
- Related: #1844190, drop 1944799.yml

* Mon Jun 29 2020 Than Ngo <than@redhat.com> - 2.0.0-2
- Related: #1844190, more fixes for #78, #79, #81, #82, #94-#97, #99, #101-#102

* Mon Jun 08 2020 Than Ngo <than@redhat.com> - 2.0.0-1
- Resolves: #1844190, rebase to 2.0.0

* Thu May 07 2020 Than Ngo <than@redhat.com> - 1.1.1-2
- Resolves: #1829495, fix summary

* Mon Oct 21 2019 Than Ngo <than@redhat.com> - 1.1.1-1
- rebase to 1.1.1
- always use ansible_hostname + ansible_domain instead of ansible_fqdn
- use {{ ansible_hostname }}.{{ ansible_domain }} instead of {{ ansible_fqdn }}
- added LC_ALL=C before commands for which the outputs are to be evaluated

* Thu Sep 12 2019 Than Ngo <than@redhat.com> - 1.1-1
- rebase to 1.1

* Fri Jun 28 2019 Than Ngo <than@redhat.com> - 1.0-1
- Initial release.
